import 'dart:io';

import 'package:image_cropper/image_cropper.dart';
import 'package:image_picker/image_picker.dart';

enum PickSource {
  /// Opens up the device camera, letting the user to take a new picture.
  camera,

  /// Opens the user's photo gallery.
  gallery,
}

Future<File> pickImageAndCropSquare(PickSource source) async {
  var image = await ImagePicker.pickImage(
      source: source == PickSource.camera
          ? ImageSource.camera
          : ImageSource.gallery);
  if (image == null) {
    return null;
  }

  File croppedFile = await ImageCropper.cropImage(
    sourcePath: image.path,
    ratioX: 1.0,
    ratioY: 1.0,
    maxWidth: 800,
    maxHeight: 800,
  );

  return croppedFile;
}

Future<File> pickImageAndCrop(PickSource source) async {
  var image = await ImagePicker.pickImage(
      source: source == PickSource.camera
          ? ImageSource.camera
          : ImageSource.gallery);
  if (image == null) {
    return null;
  }

  File croppedFile = await ImageCropper.cropImage(
    sourcePath: image.path,
    maxWidth: 800,
    maxHeight: 800,
  );

  return croppedFile;
}
